@@ -3,7 +3,10 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from typing import Any, Dict, Iterable, Union
+
 from swh.core.api import RPCClient, RemoteException
+from swh.model.model import Content
 
 from .. import HashCollision
 from ..exc import StorageAPIError, StorageArgumentException
@@ -35,6 +38,11 @@ class RemoteStorage(RPCClient):
             else:
                 raise
 
+    def content_add(self, content: Iterable[Union[Content, Dict[str, Any]]]):
+        content = [c.with_data() if isinstance(c, Content) else c
+                   for c in content]
+        return self.post('content/add', {'content': content})
+
     def reset(self):
         return self.post('reset', {})
 
