@@ -26,6 +26,7 @@ from ..exc import StorageArgumentException
 from .common import TOKEN_BEGIN, TOKEN_END
 from .converters import (
     revision_to_db, revision_from_db, release_to_db, release_from_db,
+    row_to_content_hashes,
 )
 from .cql import CqlRunner
 from .schema import HASH_ALGORITHMS
@@ -93,7 +94,11 @@ class CassandraStorage:
                     algo, content.get_hash(algo))
                 if len(pks) > 1:
                     # There are more than the one we just inserted.
-                    raise HashCollision(algo, content.get_hash(algo), pks)
+                    colliding_content_hashes = [
+                        row_to_content_hashes(pk) for pk in pks
+                    ]
+                    raise HashCollision(
+                        algo, content.get_hash(algo), colliding_content_hashes)
 
         summary = {
             'content:add': content_add,
@@ -105,7 +110,9 @@ class CassandraStorage:
         return summary
 
     def content_add(self, content: Iterable[Content]) -> Dict:
-        return self._content_add(list(content), with_data=True)
+        now = datetime.datetime.now(tz=datetime.timezone.utc)
+        contents = [attr.evolve(c, ctime=now) for c in content]
+        return self._content_add(list(contents), with_data=True)
 
     def content_update(self, content, keys=[]):
         raise NotImplementedError(
@@ -253,7 +260,9 @@ class CassandraStorage:
         }
 
     def skipped_content_add(self, content: Iterable[SkippedContent]) -> Dict:
-        return self._skipped_content_add(content)
+        now = datetime.datetime.now(tz=datetime.timezone.utc)
+        contents = [attr.evolve(c, ctime=now) for c in content]
+        return self._skipped_content_add(contents)
 
     def skipped_content_missing(self, contents):
         for content in contents:
